@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.h,v 1.4 2004/03/17 09:08:09 marco Exp $
+ *  $Id: ephy-topic-action.h,v 1.6 2004/07/02 09:03:42 marco Exp $
  */
 
 #ifndef EPHY_TOPIC_ACTION_H
@@ -47,7 +47,13 @@ struct _EphyTopicActionClass
 {
 	GtkActionClass parent_class;
 
-	void (*go_location) (EphyTopicAction *action, char *location);
+	void (*open)         (EphyTopicAction *action,
+			      char *address);
+	void (*open_in_tab)  (EphyTopicAction *action,
+			      char *address,
+			      gboolean new_window);
+	void (*open_in_tabs) (EphyTopicAction *action,
+			      GList *uri_list);
 };
 
 GType      ephy_topic_action_get_type	(void);
