@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.204 2004/08/21 16:31:49 chpe Exp $
+ *  $Id: ephy-window.c,v 1.206 2004/08/28 10:19:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -590,7 +590,6 @@ ephy_window_fullscreen (EphyWindow *window)
 
 	gtk_widget_show (popup);
 
-
 	egg_editable_toolbar_set_model
 		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
 		 EGG_TOOLBARS_MODEL (
@@ -1040,6 +1039,8 @@ update_actions_sensitivity (EphyWindow *window)
 	save_to_disk = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_SAVE_TO_DISK);
 	action = gtk_action_group_get_action (action_group, "FileSaveAs");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
+	action = gtk_action_group_get_action (action_group, "FileSave");
+	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "DownloadLink");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "SaveBackgroundAs");
@@ -2143,6 +2144,7 @@ ephy_window_init (EphyWindow *window)
 {
 	EphyExtension *manager;
 	EphyEmbedSingle *single;
+	EggToolbarsModel *model;
 
 	LOG ("EphyWindow initialising %p", window)
 
@@ -2186,6 +2188,13 @@ ephy_window_init (EphyWindow *window)
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
 	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
 
+	/* get the toolbars model *before* getting the bookmarksbar model
+	 * (via ephy_bookmarsbar_new()), so that the toolbars model is
+	 * instantiated *before* the bookmarksbarmodel, to make forwarding
+	 * works. See bug #151267.
+	 */
+	model= EGG_TOOLBARS_MODEL (ephy_shell_get_toolbars_model (ephy_shell, FALSE));
+
 	/* create the toolbars */
 	window->priv->toolbar = toolbar_new (window);
 	window->priv->bookmarksbar = ephy_bookmarksbar_new (window);
@@ -2216,9 +2225,7 @@ ephy_window_init (EphyWindow *window)
 	 * the toolbar
 	 */
 	egg_editable_toolbar_set_model
-		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
-		 EGG_TOOLBARS_MODEL
-			 (ephy_shell_get_toolbars_model (ephy_shell, FALSE)));
+		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar), model);
 
 	g_signal_connect (window, "window-state-event",
 			  G_CALLBACK (ephy_window_state_event_cb),
